"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _style = require("../utils/style");
var _SyntaxContext = require("./SyntaxContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  content: {
    padding: 10
  },
  line: {
    flexDirection: 'row'
  },
  lineContent: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  lineNumber: {
    width: 40,
    paddingRight: 8,
    opacity: 0.5
  },
  lineNumberText: {
    textAlign: 'right'
  },
  error: {
    color: '#ff6b6b'
  },
  bold: {
    fontWeight: 'bold'
  },
  italic: {
    fontStyle: 'italic'
  },
  underline: {
    textDecorationLine: 'underline'
  }
});
const SyntaxHighlighter = exports.SyntaxHighlighter = /*#__PURE__*/(0, _react.memo)(({
  code,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle,
  showLineNumbers = false,
  renderLineNumber,
  loadingComponent,
  errorComponent
}) => {
  const {
    highlighter,
    isReady
  } = (0, _SyntaxContext.useShiki)();
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [loading, setLoading] = (0, _react.useState)(true);
  const [error, setError] = (0, _react.useState)(null);
  const stylesheet = _react.default.useMemo(() => (0, _style.getStylesFromShikiTheme)(theme), [theme]);
  const highlight = (0, _react.useCallback)(async () => {
    if (!highlighter || !isReady) return;
    try {
      setLoading(true);
      setError(null);
      const normalizedLang = language.toLowerCase();
      const themeName = typeof theme === 'string' ? theme : theme.name;
      const result = highlighter.codeToTokensBase(code, {
        lang: normalizedLang,
        theme: themeName
      });
      setTokens(result);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
      console.error('Syntax highlighting error:', err);
    } finally {
      setLoading(false);
    }
  }, [code, language, theme, highlighter, isReady]);
  (0, _react.useEffect)(() => {
    highlight();
  }, [highlight]);
  const renderToken = (0, _react.useCallback)((token, lineIndex, tokenIndex) => {
    const tokenStyle = _reactNative.StyleSheet.flatten([textStyle, {
      fontSize
    }, token.color ? {
      color: token.color
    } : null, token.fontStyle === 1 && styles.italic, token.fontStyle === 2 && styles.bold, token.fontStyle === 4 && styles.underline]);
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
      style: tokenStyle,
      selectable: false,
      children: token.content
    }, `${lineIndex}-${tokenIndex}`);
  }, [fontSize, textStyle]);
  const renderLine = (0, _react.useCallback)((lineTokens, lineIndex) => {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.line,
      children: [showLineNumbers && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineNumber,
        children: renderLineNumber ? renderLineNumber(lineIndex + 1) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
          style: styles.lineNumberText,
          children: (lineIndex + 1).toString().padStart(3, ' ')
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineContent,
        children: lineTokens.map((token, tokenIndex) => renderToken(token, lineIndex, tokenIndex))
      })]
    }, lineIndex);
  }, [renderToken, showLineNumbers, renderLineNumber]);
  if (loading) {
    return loadingComponent || /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [styles.container, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ActivityIndicator, {})
    });
  }
  if (error) {
    return errorComponent?.(error) || /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [styles.container, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Text, {
        style: styles.error,
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    ...scrollViewProps,
    style: [styles.container, stylesheet.root, scrollViewProps?.style],
    contentContainerStyle: [styles.content, containerStyle],
    horizontal: true,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map